<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://www.wbcomdesigns.com
 * @since      1.0.0
 *
 * @package    Bp_Lock
 * @subpackage Bp_Lock/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Bp_Lock
 * @subpackage Bp_Lock/public
 * @author     Wbcom Designs <admin@wbcomdesigns.com>
 */
class Bp_Lock_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name	 = $plugin_name;
		$this->version		 = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function bplock_enqueue_styles() {
		wp_enqueue_style( $this->plugin_name . '-font-awesome', BPLOCK_PLUGIN_URL . 'admin/css/font-awesome.min.css' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/bp-lock-public.css' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function bplock_enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/bp-lock-public.js', array( 'jquery' ) );
		wp_localize_script(
		$this->plugin_name, 'bplock_public_js_object', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' )
		)
		);
	}

	/**
	 * Modify the template of the locked pages.
	 *
	 * @since    1.0.0
	 */
	public function bplock_lock_pages( $template ) {
		global $post, $bplock, $wp;
		$current_url = home_url( $wp->request );
		$match		 = false;
		if ( !empty( $bplock->locked_pages ) ) {
			foreach ( $bplock->locked_pages as $pid ) {
				$slug = basename( get_permalink( $pid ) );
				if ( strpos( $current_url, $slug ) !== FALSE ) {
					$match = true;
				}
			}
		}
		if ( !is_user_logged_in() && $bplock->lock_wp_pages == 'yes' && !empty( $bplock->locked_pages ) && !empty( $post ) && in_array( $post->ID, $bplock->locked_pages ) || !is_user_logged_in() && $bplock->lock_wp_pages == 'yes' && !empty( $bplock->locked_pages ) && $match ) {
			if ( file_exists( $bplock->locked_content_template ) ) {
				$template = $bplock->locked_content_template;
			}
		}
		return $template;
	}

	public function bplock_exclude_search( $query ) {
		global $bplock, $bp, $wp;
		$match = array();
		if ( !is_user_logged_in() && !empty( $bplock->locked_bp_components ) && $bplock->lock_bp_components == 'yes' ) {
			foreach ( $bplock->locked_bp_components as $bpc ) {
				$pid = get_page_by_path( $bpc );
				if ( $pid ) {
					$match[] = $pid->ID;
				}
			}
		}

		if ( !is_user_logged_in() && $bplock->lock_wp_pages == 'yes' && !empty( $bplock->locked_pages ) ) {
			foreach ( $bplock->locked_pages as $pid ) {
				if ( $pid ) {
					if ( !in_array( $pid, $match ) ) {
						$match[] = $pid;
					}
				}
			}
		}
		$match_cpt	 = array();
		$cpts		 = array();
		if ( !is_user_logged_in() && $bplock->lock_cpt == 'yes' && !empty( $bplock->locked_cpts ) ) {
			$args	 = array( 'public' => true, '_builtin' => false, 'exclude_from_search' => false );
			$cpts	 = get_post_types( $args, 'name' );
			if ( !empty( $cpts ) ) {
				$cpts = array_keys( $cpts );
			}
			foreach ( $bplock->locked_cpts as $cpt ) {
				if ( $cpt ) {
					$match_cpt[] = $cpt;
				}
			}
		}
		$new_cpts = array();
		if ( !empty( $match_cpt ) && !empty( $cpts ) ) {
			foreach ( $cpts as $key => $cpt ) {
				if ( !in_array( $cpt, $match_cpt ) ) {
					$new_cpts[] = $cpt;
				}
			}
		}
		if ( $query->is_search ) {
			if ( !empty( $match ) ) {
				$query->set( 'post__not_in', $match );
			}
			if ( !empty( $new_cpts ) ) {
				$query->set( 'post_type', $new_cpts );
			}
		}

		return $query;
	}

	/**
	 * Modify the archive template of the locked custom post types.
	 *
	 * @since    1.0.0
	 */
	public function bplock_lock_cpts( $template ) {
		global $post, $bplock;
		if ( !is_user_logged_in() && $bplock->lock_cpt == 'yes' && !empty( $bplock->locked_cpts ) && !empty( $post ) && in_array( $post->post_type, $bplock->locked_cpts ) ) {
			if ( file_exists( $bplock->locked_content_template ) ) {
				$template = $bplock->locked_content_template;
			}
		}
		return $template;
	}

	/**
	 * Modify the single template of the locked custom post types.
	 *
	 * @since    1.0.0
	 */
	public function bplock_lock_cpt_single( $template ) {
		global $post, $bplock;

		if ( !is_user_logged_in() && $bplock->lock_cpt == 'yes' && !empty( $bplock->locked_cpts ) && !empty( $post ) && in_array( $post->post_type, $bplock->locked_cpts ) ) {
			if ( file_exists( $bplock->locked_content_template ) ) {
				$template = $bplock->locked_content_template;
			}
		}
		return $template;
	}

	/**
	 * Modify the single template of the locked custom post types.
	 *
	 * @since    1.0.0
	 */
	public function bplock_lock_bp_components( $found_template, $templates ) {
		global $bplock, $bp, $wp;
		$current_url = home_url( $wp->request );
		$match		 = false;
		if ( !empty( $bplock->locked_bp_components ) && $bplock->lock_bp_components == 'yes' ) {
			foreach ( $bplock->locked_bp_components as $url ) {
				if ( strpos( $current_url, $url ) !== FALSE ) {
					$match = true;
				}
			}
		}
		if ( !is_user_logged_in() && $bplock->lock_bp_components == 'yes' && !empty( $bplock->locked_bp_components ) && in_array( $bp->current_component, $bplock->locked_bp_components ) || !is_user_logged_in() && $bplock->lock_bp_components == 'yes' && !empty( $bplock->locked_bp_components ) && $match ) {
			if ( file_exists( $bplock->locked_content_template ) ) {
				$found_template = $bplock->locked_content_template;
			}
		}
		return $found_template;
	}

	/**
	 * The shortcode template for user login
	 *
	 * @since    1.0.0
	 */
	public function bplock_login_form_template() {
		global $bplock;
        $locked_content = $bplock->locked_content;
        if ( empty( $locked_content ) ) {
            $locked_content = apply_filters( 'bploc_default_locked_message', __( 'Hey Member! Thanks for checking this page out -- however, it’s restricted to logged members only. If you’d like to access it, please login to the website.', BPLOCK_TEXT_DOMAIN ) );
        }
				?>
        <div class="bplock-content"></div>
        <p class="bplock-locked-message"><?php echo $locked_content; ?></p>
		<div class="bplock-login-form-container">
			<ul class="bplock-login-shortcode-tabs">
				<li class="tab-link current" id="bplock-login-tab" data-tab="tab-login"><i class="fa fa-sign-in" aria-hidden="true"></i> <?php _e( 'Login', BPLOCK_TEXT_DOMAIN ); ?></li>
				<li class="tab-link" id="bplock-register-tab" data-tab="tab-register"><i class="fa fa-user-plus" aria-hidden="true"></i> <?php _e( 'Register', BPLOCK_TEXT_DOMAIN ); ?></li>
			</ul>
			<div id="tab-login" class="tab-content current">
				<?php
				$file = BPLOCK_PLUGIN_PATH . 'public/templates/bplock-login-form.php';
				if ( file_exists( $file ) ) {
					include_once $file;
				}
				?>
			</div>
			<div id="tab-register" class="tab-content">
				<?php
				$file = BPLOCK_PLUGIN_PATH . 'public/templates/bplock-register-form.php';
				if ( file_exists( $file ) ) {
					include_once $file;
				}
				?>
			</div>
		</div>
		</div>
		<?php
	}

	/**
	 * AJAX server, to login the user
	 */
	function bplock_login() {
		if ( isset( $_POST[ 'action' ] ) && $_POST[ 'action' ] == 'bplock_login' ) {
			$username	 = sanitize_text_field( $_POST[ 'username' ] );
			$password	 = sanitize_text_field( $_POST[ 'password' ] );


			$credentials	 = array(
				'user_login'	 => sanitize_text_field( $_POST[ 'username' ] ),
				'user_password'	 => sanitize_text_field( $_POST[ 'password' ] ),
				'remember'		 => true
			);
			$secure_cookie	 = true;
			$user			 = wp_signon( $credentials, $secure_cookie );
			if ( is_wp_error( $user ) ) {
				$login_success	 = 'no';
				$msg			 = $user->get_error_message();
			} else {
				$login_success	 = 'yes';
				$msg			 = __( 'Login successful! Redirecting...', BPLOCK_TEXT_DOMAIN );
			}
			$response = array(
				'message'		 => apply_filters( 'bplock_login_success_message', $msg ),
				'login_success'	 => $login_success
			);
			wp_send_json_success( $response );
			die;
		}
	}

	/**
	 * AJAX server, to register the user
	 */
	function bplock_register() {
		if ( isset( $_POST[ 'action' ] ) && $_POST[ 'action' ] == 'bplock_register' ) {
			$email		 = sanitize_text_field( $_POST[ 'email' ] );
			$username	 = sanitize_text_field( $_POST[ 'username' ] );
			$password	 = sanitize_text_field( $_POST[ 'password' ] );
			$user		 = get_user_by( 'email', $email );

			if ( !empty( $user ) ) {
				$register_success	 = 'no';
				$msg				 = apply_filters( 'bplock_register_user_already_exists_message', __( 'User account already exists with the requested email!', BPLOCK_TEXT_DOMAIN ) );
			} else {
				$user_id		 = wp_create_user( $username, $password, $email );
				$credentials	 = array(
					'user_login'	 => $username,
					'user_password'	 => $password,
					'remember'		 => true
				);
				$secure_cookie	 = true;
				$loggedin_user	 = wp_signon( $credentials, $secure_cookie );
				if ( is_wp_error( $user ) ) {
					$register_success	 = 'no';
					$msg				 = $loggedin_user->get_error_message();
				} else {
					$register_success	 = 'yes';
					$msg				 = apply_filters( 'bplock_register_success_message', __( 'User registered! Logging in...', BPLOCK_TEXT_DOMAIN ) );
				}
			}
			$response = array(
				'message'			 => $msg,
				'register_success'	 => $register_success
			);
			wp_send_json_success( $response );
			die;
		}
	}

}
